@@ -67,10 +67,9 @@ enum
 static GParamSpec *properties [N_PROPS];
 
 /**
- * SECTION:cloudprovidersaccountexporter
- * @title: CloudProvidersAccountExporter
- * @short_description: Base object for representing a cloud providers account
- * @include: src/cloudprovidersaccountexporter.h
+ * CloudProvidersAccountExporter:
+ *
+ * Base object for representing a cloud providers account
  */
 
 static void
@@ -146,10 +145,9 @@ cloud_providers_account_exporter_get_skeleton (CloudProvidersAccountExporter *se
 /**
  * cloud_providers_account_exporter_new:
  * @provider: The provider to which it will be associated.
- * @bus_name: A unique name for the account
- *               must be a valid DBus object name
+ * @bus_name: A unique name for the account. Must be a valid DBus object name.
  *
- * Create a new #CloudProvidersAccountExporter object
+ * Create a new [class@AccountExporter] object
  */
 CloudProvidersAccountExporter*
 cloud_providers_account_exporter_new (CloudProvidersProviderExporter *provider,
@@ -206,9 +204,6 @@ cloud_providers_account_exporter_get_property (GObject    *object,
 
         case PROP_ICON:
         {
-            g_autoptr (GIcon) icon = NULL;
-
-            icon = g_icon_new_for_string (self->icon, NULL);
             g_value_take_object (value, g_icon_new_for_string (self->icon, NULL));
         }
         break;
@@ -364,7 +359,7 @@ cloud_providers_account_exporter_set_icon (CloudProvidersAccountExporter *self,
  * @menu_model: The menu model to export
  *
  * One of the benefits of the integration is to display a menu with available
- * options for an account. Use this function to export a GMenuModel menu to be
+ * options for an account. Use this function to export a [class@Gio.MenuModel] menu to be
  * displayed by the chosen integration by the desktop environment or application.
  */
 void
@@ -383,11 +378,10 @@ cloud_providers_account_exporter_set_menu_model (CloudProvidersAccountExporter *
 /**
  * cloud_providers_account_exporter_set_action_group:
  * @self: The cloud provider
- * @action_group: The GActionGroup to be used by the menu exported by cloud_providers_account_exporter_export_menu
+ * @action_group: The action group to be used to render the menu
  *
- * In order for a menu exported with cloud_providers_account_exporter_export_menu to receive events
- * that will eventually call your callbacks, it needs the corresponding GActionGroup.
- * Use this function to export it.
+ * In order for a menu to receive events that will eventually call your callbacks, it needs the
+ * corresponding [iface@Gio.ActionGroup]. Use this function to export it.
  */
 void
 cloud_providers_account_exporter_set_action_group (CloudProvidersAccountExporter *self,
@@ -470,89 +464,108 @@ cloud_providers_account_exporter_class_init (CloudProvidersAccountExporterClass
     object_class->dispose = cloud_providers_account_exporter_dispose;
     object_class->finalize = cloud_providers_account_exporter_finalize;
 
+    /**
+     * CloudProvidersAccountExporter:name:
+     *
+     * The name of the account.
+     */
     properties [PROP_NAME] =
-        g_param_spec_string ("name",
-                             "Name",
-                             "The name of the account",
+        g_param_spec_string ("name", NULL, NULL,
                              NULL,
                              (G_PARAM_READWRITE |
                               G_PARAM_STATIC_STRINGS));
-    g_object_class_install_property (object_class, PROP_NAME,
-                                     properties [PROP_NAME]);
+
+    /**
+     * CloudProvidersAccountExporter:bus-name:
+     *
+     * The bus name of the account.
+     */
     properties [PROP_BUS_NAME] =
-        g_param_spec_string ("bus-name",
-                             "BusName",
-                             "The bus name of the account",
+        g_param_spec_string ("bus-name", NULL, NULL,
                              NULL,
                              (G_PARAM_READWRITE |
                               G_PARAM_STATIC_STRINGS|
                               G_PARAM_CONSTRUCT_ONLY));
-    g_object_class_install_property (object_class, PROP_BUS_NAME,
-                                     properties [PROP_BUS_NAME]);
+
+    /**
+     * CloudProvidersAccountExporter:provider:
+     *
+     * The provider associated with the account.
+     */
     properties [PROP_PROVIDER] =
-        g_param_spec_object ("provider",
-                             "Provider",
-                             "The provider associated with the account",
+        g_param_spec_object ("provider", NULL, NULL,
                              CLOUD_PROVIDERS_TYPE_PROVIDER_EXPORTER,
                              (G_PARAM_READWRITE |
                               G_PARAM_STATIC_STRINGS |
                               G_PARAM_CONSTRUCT_ONLY));
-    g_object_class_install_property (object_class, PROP_PROVIDER,
-                                     properties [PROP_PROVIDER]);
+
+    /**
+     * CloudProvidersAccountExporter:path:
+     *
+     * The path of the directory where files are located.
+     */
     properties [PROP_PATH] =
-        g_param_spec_string ("path",
-                             "Path",
-                             "The path of the directory where files are located",
+        g_param_spec_string ("path", NULL, NULL,
                              NULL,
                              (G_PARAM_READWRITE |
                               G_PARAM_STATIC_STRINGS));
-    g_object_class_install_property (object_class, PROP_PATH,
-                                     properties [PROP_PATH]);
+
+    /**
+     * CloudProvidersAccountExporter:status:
+     *
+     * Status of the account.
+     */
     properties [PROP_STATUS] =
-        g_param_spec_enum ("status",
-                          "Status",
-                          "Status of the account",
-                          CLOUD_TYPE_PROVIDERS_ACCOUNT_STATUS,
-                          CLOUD_PROVIDERS_ACCOUNT_STATUS_INVALID,
-                          (G_PARAM_READWRITE |
-                           G_PARAM_STATIC_STRINGS));
-    g_object_class_install_property (object_class, PROP_STATUS,
-                                     properties [PROP_STATUS]);
+        g_param_spec_enum ("status", NULL, NULL,
+                           CLOUD_TYPE_PROVIDERS_ACCOUNT_STATUS,
+                           CLOUD_PROVIDERS_ACCOUNT_STATUS_INVALID,
+                           (G_PARAM_READWRITE |
+                            G_PARAM_STATIC_STRINGS));
+
+    /**
+     * CloudProvidersAccountExporter:status-details:
+     *
+     * The details of the account status.
+     */
     properties [PROP_STATUS_DETAILS] =
-        g_param_spec_string ("status-details",
-                             "StatusDetails",
-                             "The details of the account status",
+        g_param_spec_string ("status-details", NULL, NULL,
                              NULL,
                              (G_PARAM_READWRITE |
                               G_PARAM_STATIC_STRINGS));
-    g_object_class_install_property (object_class, PROP_STATUS_DETAILS,
-                                     properties [PROP_STATUS_DETAILS]);
+
+    /**
+     * CloudProvidersAccountExporter:icon:
+     *
+     * The icon representing the account.
+     */
     properties [PROP_ICON] =
-        g_param_spec_object ("icon",
-                             "Icon",
-                             "The icon representing the account",
+        g_param_spec_object ("icon", NULL, NULL,
                              G_TYPE_ICON,
                              (G_PARAM_READWRITE |
                               G_PARAM_STATIC_STRINGS));
-    g_object_class_install_property (object_class, PROP_ICON,
-                                     properties [PROP_ICON]);
+
+    /**
+     * CloudProvidersAccountExporter:menu-model:
+     *
+     * The menu model associated with the account.
+     */
     properties [PROP_MENU_MODEL] =
-        g_param_spec_object ("menu-model",
-                             "MenuModel",
-                             "The menu model associated with the account",
+        g_param_spec_object ("menu-model", NULL, NULL,
                              G_TYPE_MENU_MODEL,
                              (G_PARAM_READWRITE |
                               G_PARAM_STATIC_STRINGS));
-    g_object_class_install_property (object_class, PROP_MENU_MODEL,
-                                     properties [PROP_MENU_MODEL]);
+
+    /**
+     * CloudProvidersAccountExporter:action-group:
+     *
+     * The action group associated with the account and menu model.
+     */
     properties [PROP_ACTION_GROUP] =
-        g_param_spec_object ("action-group",
-                             "ActionGroup",
-                             "The action group associated with the account and menu model",
+        g_param_spec_object ("action-group", NULL, NULL,
                              G_TYPE_ACTION_GROUP,
                              (G_PARAM_READWRITE |
                               G_PARAM_STATIC_STRINGS));
-    g_object_class_install_property (object_class, PROP_ACTION_GROUP,
-                                     properties [PROP_ACTION_GROUP]);
+
+    g_object_class_install_properties (object_class, N_PROPS, properties);
 }
 
