@@ -40,14 +40,12 @@ struct _CloudProvidersProvider
 G_DEFINE_TYPE (CloudProvidersProvider, cloud_providers_provider, G_TYPE_OBJECT)
 
 /**
- * SECTION:cloudprovidersprovider
- * @title: CloudProvidersProvider
- * @short_description: Base object for representing a single provider for clients.
- * @include: src/cloudprovidersprovider.h
+ * CloudProvidersProvider:
  *
- * #CloudProvidersProvider is the basic object object for client implementers
- * that contains the properties of the provider such as name, and the accounts
- * associated with it.
+ * Base object for representing a single provider for clients.
+ *
+ * This is the basic object object for client implementers that contains the properties of the
+ * provider such as name, and the accounts associated with it.
  */
 
 enum
@@ -207,10 +205,13 @@ cloud_providers_provider_class_init (CloudProvidersProviderClass *klass)
     object_class->get_property = cloud_providers_provider_get_property;
     object_class->set_property = cloud_providers_provider_set_property;
 
+    /**
+     * CloudProvidersProvider:name:
+     *
+     * The name of the cloud provider.
+     */
     properties [PROP_NAME] =
-        g_param_spec_string ("name",
-                             "Name",
-                             "Name of the provider",
+        g_param_spec_string ("name", NULL, NULL,
                              NULL,
                              (G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
     g_object_class_install_properties (object_class,
@@ -439,7 +440,10 @@ cloud_providers_provider_get_name (CloudProvidersProvider *self)
 /**
  * cloud_providers_provider_get_accounts
  * @self: A CloudProvidersProvider
- * Returns: (element-type CloudProviders.Account) (transfer none): A GList* of #CloudProvidersProvider objects.
+ *
+ * Get the list of accounts from this provider.
+ *
+ * Returns: (element-type CloudProvidersAccount) (transfer none): A list of [class@Account] objects.
  */
 GList*
 cloud_providers_provider_get_accounts (CloudProvidersProvider *self)
