@@ -55,14 +55,9 @@ enum
 static GParamSpec *properties [N_PROPS];
 
 /**
- * SECTION:cloudprovidersproviderexporter
- * @title: CloudProvidersProviderExporter
- * @short_description: Base object for representing a single provider
- * @include: src/cloudprovidersexporter.h
+ * CloudProvidersProviderExporter:
  *
- * #CloudProvidersProviderExporter is the base object representing a single cloud provider.
- * Multiple #CloudProvidersAccountExporter objects can be added with cloud_providers_provider_exporter_add_account()
- * After adding the initial set of accounts cloud_providers_provider_exporter_export_objects() must be called.
+ * Base object for representing a single single provider.
  */
 
 static void
@@ -116,7 +111,7 @@ unexport_account(CloudProvidersProviderExporter *self,
  * Each cloud provider can have a variety of account associated with it. Use this
  * function to add the accounts the user set up. This function is currently only internal,
  * as we do automation for the dbus handling for adding and exporting an account.
- * This is handled in cloud_providers_account_exporter_new().
+ * This is handled in [ctor@AccountExporter.new].
  */
 void
 cloud_providers_provider_exporter_add_account (CloudProvidersProviderExporter *self,
@@ -132,7 +127,7 @@ cloud_providers_provider_exporter_add_account (CloudProvidersProviderExporter *s
  * @account: The account object
  *
  * Each cloud provider can have a variety of account associated with it. Use this
- * function to remove the accounts that were added when created by cloud_providers_account_exporter_new().
+ * function to remove the accounts that were added when created by [ctor@AccountExporter.new].
  */
 void
 cloud_providers_provider_exporter_remove_account (CloudProvidersProviderExporter *self,
@@ -292,34 +287,48 @@ cloud_providers_provider_exporter_class_init (CloudProvidersProviderExporterClas
     object_class->dispose = cloud_providers_provider_exporter_dispose;
     object_class->finalize = cloud_providers_provider_exporter_finalize;
 
+    /**
+     * CloudProvidersProviderExporter:name:
+     *
+     * The name of the cloud provider.
+     */
     properties [PROP_NAME] =
-        g_param_spec_string ("name",
-                             "Name",
-                             "The name of the cloud provider",
+        g_param_spec_string ("name", NULL, NULL,
                              NULL,
                              (G_PARAM_READWRITE |
                               G_PARAM_STATIC_STRINGS));
+
+    /**
+     * CloudProvidersProviderExporter:bus-name:
+     *
+     * The bus name of the provider.
+     */
     properties [PROP_BUS_NAME] =
-        g_param_spec_string ("bus-name",
-                             "BusName",
-                             "BusName",
-                             NULL,
-                             (G_PARAM_READWRITE |
-                              G_PARAM_STATIC_STRINGS |
-                              G_PARAM_CONSTRUCT_ONLY));
-    properties [PROP_BUS_PATH] =
-        g_param_spec_string ("bus-path",
-                             "BusPath",
-                             "BusPath",
+        g_param_spec_string ("bus-name", NULL, NULL,
                              NULL,
                              (G_PARAM_READWRITE |
                               G_PARAM_STATIC_STRINGS |
                               G_PARAM_CONSTRUCT_ONLY));
 
+    /**
+     * CloudProvidersProviderExporter:bus-path:
+     *
+     * The bus path of the provider.
+     */
+    properties [PROP_BUS_PATH] =
+        g_param_spec_string ("bus-path", NULL, NULL,
+                             NULL,
+                             (G_PARAM_READWRITE |
+                              G_PARAM_STATIC_STRINGS |
+                              G_PARAM_CONSTRUCT_ONLY));
+
+    /**
+     * CloudProvidersProviderExporter:bus:
+     *
+     * The bus connection object for the provider.
+     */
     properties [PROP_BUS] =
-        g_param_spec_object ("bus",
-                             "Bus",
-                             "Bus",
+        g_param_spec_object ("bus", NULL, NULL,
                              G_TYPE_DBUS_CONNECTION,
                              (G_PARAM_READWRITE |
                               G_PARAM_STATIC_STRINGS |
@@ -344,7 +353,7 @@ cloud_providers_provider_exporter_get_name (CloudProvidersProviderExporter *self
 
 /**
  * cloud_providers_provider_exporter_new
- * @bus: A #GDBusConnection to export the objects to
+ * @bus: A connection to export the objects to
  * @bus_name: A DBus name to bind to
  * @bus_path: A DBus object path
  */
